@@ -6,13 +6,13 @@
 #' configurations, where missing landmarks in the incomplete specimens are designated by NA in place 
 #' of the x,y,z coordinates.  Two distinct approaches are implemented.
 #' 
-#' The first approach (method="TPS") uses the thin-plate spline to interpolate landmarks on a reference specimen to estimate 
+#' The first approach (method = "TPS") uses the thin-plate spline to interpolate landmarks on a reference specimen to estimate 
 #' the locations of missing landmarks on a target specimen. Here, a reference specimen is obtained from 
 #' the set of specimens for which all landmarks are present, Next, each incomplete specimen is aligned to 
 #' the reference using the set of landmarks common to both. Finally, the thin-plate spline is used 
 #' to estimate the locations of the missing landmarks in the target specimen (Gunz et al. 2009).
 #' 
-#' The second approach (method="Reg") is multivariate regression. Here each landmark with missing values is
+#' The second approach (method = "Reg") is multivariate regression. Here each landmark with missing values is
 #' regressed on all other landmarks for the set of complete specimens, and the missing landmark values are
 #' then predicted by this linear regression model. Because the number of variables can exceed the number of
 #' specimens, the regression is implemented on scores along the first set of PLS axes for the complete and 
@@ -51,14 +51,16 @@
 #' @references Gunz, P., P. Mitteroecker, S. Neubauer, G. W. Weber, and F. L. Bookstein. 2009. Principles for 
 #' the virtual reconstruction of hominin crania. J. Hum. Evol. 57:48-62.
 #' @examples
+#' \dontrun{
 #' data(plethodon)
-#' plethland<-plethodon$land
-#'   plethland[3,,2]<-plethland[8,,2]<-NA  #create missing landmarks
-#'   plethland[3,,5]<-plethland[8,,5]<-plethland[9,,5]<-NA  
-#'   plethland[3,,10]<-NA  
+#' plethland <- plethodon$land
+#'   plethland[3,,2] <- plethland[8,,2] <- NA  #create missing landmarks
+#'   plethland[3,,5] <- plethland[8,,5] <- plethland[9,,5] <- NA  
+#'   plethland[3,,10] <- NA  
 #'   
-#' estimate.missing(plethland,method="TPS")
-#' estimate.missing(plethland,method="Reg")
+#' estimate.missing(plethland, method = "TPS")
+#' estimate.missing(plethland, method = "Reg")
+#' }
 estimate.missing <- function(A, method=c("TPS","Reg")){
   if(inherits(A, "geomorphShapes")) {
     a <- A
@@ -161,10 +163,10 @@ estimate.missing <- function(A, method=c("TPS","Reg")){
     A2 <- simplify2array(A2.updated)
     dimnames(A2) <- A.names
   }
-  if("a" %in% ls()) {
-    a$landmarks <- A2.updated
-    names(A2.updated) <- A.names[[3]]
-    A2 <- a
-  }
+  #  if("a" %in% ls()) {
+  #    a$landmarks <- A2.updated
+  #    names(A2.updated) <- A.names[[3]]
+  #    A2 <- a
+  #  }
    return(A2)
 }
